#!/bin/bash

TEXTDOMAIN=`basename $0`
#if [ -d "./locale" ]; then
#  TEXTDOMAINDIR="./locale"
#fi

. /etc/3cp4218

echo $">>> Inits 3Com ADSL Modem USB <<<"
echo

FLOAD_NAME=3cload
MODULE_NAME=3cp4218
MODULE_NAMEDBG=3cp4218dbg

remove_driver() {
  # Remove module if it is loaded, we only have 1 interface, this is need to load firmware
  driver=`lsmod | cut -d' ' -f1 | grep -E "^$MODULE_REMOVE_NAME$"`
  if [ "$driver" != "" ]; then
    echo $">>> Removing 3cp4218 driver..."
    rmmod $driver || exit 1
    echo
    sleep 1s
  fi
}

# Load usb host controller if is not loaded
KERNEL_VERSION=`uname -r | cut -d'.' -f1-2`
if [ "$KERNEL_VERSION" = "2.4" ]; then
  usbcon=`lsmod | cut -d ' ' -f1 | grep -E "^uhci|usb-uhci|usb-ohci|ehci-hcd$"`
  if [ "$usbcon" = "" ]; then
    echo $">>> Loading USB controller..."
    modprobe uhci > /dev/null || modprobe usb-ohci > /dev/null || modprobe ehci-hcd > /dev/null
    sleep 5s
    echo
  fi
else
  usbcon=`lsmod | cut -d ' ' -f1 | grep -E "^uhci_hcd|ohci_hcd|ehci_hcd$"`
  if [ "$usbcon" = "" ]; then
    echo $">>> Loading USB controller..."
    modprobe uhci-hcd
    modprobe ohci-hcd
    modprobe ehci-hcd
    sleep 5s
    echo
  fi
fi

# Mount USB file systems if is not mounted
mt_old=`mount -t usbdevfs`
mt_new=`mount -t usbfs`
if [ "$mt_old" = "" ] && [ "$mt_new" = "" ]; then
  echo $">>> Mounting USB file system..."
  mount -t usbfs usbfs /proc/bus/usb || mount -t usbdevfs none /proc/bus/usb || exit 1
  echo
fi

# Driver for kernels 2.4 and 2.6 can be loaded before (two drivers: normal and debug)
MODULE_REMOVE_NAME=$MODULE_NAME
remove_driver
MODULE_REMOVE_NAME=$MODULE_NAMEDBG
remove_driver

# Load EZ-USB firmware
echo $">>> Loading EZ-USB firmware..."
$FLOAD_NAME 1 $BINARY_PATH/ez-usb.bin || exit 1

# Wait renum process
sleep 5s
echo

# Load Alcatel firmware
echo $">>> Loading Alcatel firmware..."
$FLOAD_NAME 2 $BINARY_PATH/3cinit.bin $BINARY_PATH/3cmain.bin $OPEN_MODE || exit 1
echo

# Driver for kernels 2.4 and 2.6 is loaded after renum process (two drivers: normal and debug)
MODULE_REMOVE_NAME=$MODULE_NAME
remove_driver
MODULE_REMOVE_NAME=$MODULE_NAMEDBG
remove_driver

if [ "$MONITORIZE_LINE" != "" ] && [ "$MONITORIZE_LINE" -eq 1 ] ; then
  # Monitorize ADSL line 
  $FLOAD_NAME 3 || exit 1
  exit 0
else
  # Load 3Com module (incompatible with Monitorize ADSL line)
  echo $">>> Loading driver..."

  if [ "$KERNEL_VERSION" != "2.4" ]; then
    crc32=`lsmod | cut -d ' ' -f1 | grep -E "^crc32$"`
    if [ "$crc32" = "" ]; then
      modprobe crc32
    fi
  fi

  case "$DRIVER_MODE" in
    1)
       # normal mode:
       echo $"Launching driver in normal mode...";
       MODULE_RUN=$MODULE_NAME
       SPEED_OPTION=0
       ;;

    2)
       # debug mode:
       echo $"Launching driver in debug mode...";
       MODULE_RUN=$MODULE_NAMEDBG
       SPEED_OPTION=0
       ;;

    3)
       # normal + max speed mode:
       echo $"Launching driver in normal + max speed mode...";
       MODULE_RUN=$MODULE_NAME
       SPEED_OPTION=1
       ;;

    4)
       # debug + max speed mode:
       echo $"Launching driver in debug + max speed mode...";
       MODULE_RUN=$MODULE_NAMEDBG
       SPEED_OPTION=1
       ;;
  esac
  modprobe $MODULE_RUN speed=$SPEED_OPTION open=$OPEN_MODE || exit 1
  sleep 3s 
fi

echo
echo $0 $"successful"

