#!/bin/bash

#variables
TARGET=/tmp/3cp4218-deb-pkg
VERSION=`date +%Y-%m-%d`_`uname -r`
MAINTAINER="Josep Comas <jcomas@gna.es>"
DATE=`date -R`
if [ "$1" = "" ]; then
  DEST_MACHINE=`uname -m`
else
  DEST_MACHINE=$1
fi
FILE_CONTROL="$TARGET"/DEBIAN/control
FILE_COPYRIGHT="$TARGET"/DEBIAN/copyright
FILE_CHANGELOG="$TARGET"/DEBIAN/changelog
FILE_CONFFILES="$TARGET"/DEBIAN/conffiles
FILE_POSTINST="$TARGET"/DEBIAN/postinst
FILE_PRERM="$TARGET"/DEBIAN/prerm
SOURCE_BIN=/usr/sbin
SOURCE_LC_ES=/usr/share/locale/es/LC_MESSAGES
SOURCE_MODULE=/lib/modules/`uname -r`/kernel/drivers/usb
PACKAGE_NAME=../../3cp4218-`date +%Y-%m-%d`.k`uname -r`."$DEST_MACHINE".deb
SHLIBDEPS=`dpkg-shlibdeps -O $SOURCE_BIN/3cload $SOURCE_BIN/3cioctl $SOURCE_BIN/br2684ctl $SOURCE_BIN/3cpanel $SOURCE_BIN/3cconfig | sed 's/shlibs:Depends=//g'` 


#
#create DEBIAN directory and create files to build deb package
#

rm -rf $TARGET
mkdir -p $TARGET/DEBIAN

#Architecture: $DEST_MACHINE changed by Architecture: i386

cat > $FILE_CONTROL << EOF
Source: 3cp4218
Section: contrib/net
Priority: optional
Maintainer: $MAINTAINER
Package: 3cp4218
Architecture: i386
Version: $VERSION
Depends: $SHLIBDEPS
Description: Conexant AccessRunner USB ADSL modem kernel space driver
 This package contains software to use Conexant AccessRunner USB ADSL modem
 under Linux. It supports several protocols.
EOF

cat > $FILE_COPYRIGHT << EOF
$DATE

It was downloaded from: http://sourceforge.net/projects/accessrunner/

Upstream author: $MAINTAINER

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as
published by the Free Software Foundation; either version 2 of
the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

On Debian systems, the complete text of the GNU General Public
License can be found in /usr/share/common-licenses/GPL file.
EOF

cat > $FILE_CHANGELOG << EOF
3cp4218 ($VERSION) unstable; urgency=low

  * Maintaining the Debian package myself.

 -- $MAINTAINER  $DATE 
EOF

cat > $FILE_CONFFILES << EOF
/etc/3cp4218
EOF

cat > $FILE_POSTINST << EOF
#!/bin/bash
/sbin/depmod -a
if [ -f /etc/debian_version ]; then 
  install -c -m 755 -p /etc/cp4218.service /etc/init.d/cp4218; 
  update-rc.d cp4218 defaults; 
  update-rc.d -f atm remove; 
else 
  if [ -f /etc/redhat-release ]; then 
    install -c -m 755 -p /etc/cp4218.service /etc/rc.d/init.d/cp4218; 
    chkconfig --add cp4218; 
  else 
    if [ -f /etc/SuSE-release ] ; then 
      install -c -m 755 -p /etc/cp4218.service /etc/init.d/cp4218; 
      install -c -m 755 -p /etc/cp4218.service /etc/rc.d/cp4218; 
      insserv cp4218; 
    else 
      if [ -f /etc/slackware-version ] ; then 
        if grep -q -E "^ */usr/sbin/3cstart.sh *$" /etc/rc.d/rc.local; then 
          cd /etc/rc.d; 
          cp -f rc.local rc.local.tmp; 
          echo "/usr/sbin/3cstart.sh" >> rc.local.tmp; 
          mv -f rc.local.tmp rc.local; 
        fi 
      fi 
    fi 
  fi 
fi
EOF

cat > $FILE_PRERM << EOF
#!/bin/bash
if [ -f /etc/debian_version ]; then 
        update-rc.d -f cp4218 remove; 
        rm -f /etc/init.d/cp4218; 
else 
        if [ -f /etc/redhat-release ]; then 
                chkconfig --del cp4218; 
                rm -f /etc/rc.d/init.d/cp4218; 
        else 
                if [ -f /etc/SuSE-release ] ; then 
                        insserv -r cp4218; 
                        rm -f /etc/init.d/cp4218; 
                        rm -f /etc/rc.d/cp4218; 
                else 
                        if [ -f /etc/slackware-version ] ; then 
                                cd /etc/rc.d; 
                                grep -v -E "^ */usr/sbin/3cstart.sh *$" rc.local > rc.local.tmp; 
                                mv -f rc.local.tmp rc.local; 
                        fi 
                fi 
        fi 
fi
EOF

chmod 644 $FILE_CONTROL
chmod 644 $FILE_COPYRIGHT
chmod 644 $FILE_CHANGELOG
chmod 644 $FILE_CONFFILES
chmod 755 $FILE_POSTINST
chmod 755 $FILE_PRERM


#
#copy driver files in temp directory for deb package
#

mkdir -p $TARGET$SOURCE_BIN
mkdir -p $TARGET$SOURCE_LC_ES
mkdir -p $TARGET$SOURCE_MODULE
mkdir -p $TARGET/etc

#init
cp -p $SOURCE_BIN/3cload $TARGET$SOURCE_BIN 
cp -p $SOURCE_BIN/3cioctl $TARGET$SOURCE_BIN
cp -p $SOURCE_LC_ES/3cload.mo $TARGET$SOURCE_LC_ES
cp -p $SOURCE_LC_ES/3cioctl.mo $TARGET$SOURCE_LC_ES

#firmware
cp -p $SOURCE_BIN/ez-usb.bin $TARGET$SOURCE_BIN
cp -p $SOURCE_BIN/3cinit.bin $TARGET$SOURCE_BIN
cp -p $SOURCE_BIN/3cmain.bin $TARGET$SOURCE_BIN

#module
KERNEL_VERSION=`uname -r | cut -d'.' -f1-2`
if [ "$KERNEL_VERSION" = "2.4" ]; then
  cp -p $SOURCE_MODULE/3cp4218.o $TARGET$SOURCE_MODULE
  cp -p $SOURCE_MODULE/3cp4218dbg.o $TARGET$SOURCE_MODULE
else
  cp -p $SOURCE_MODULE/3cp4218.ko $TARGET$SOURCE_MODULE
  cp -p $SOURCE_MODULE/3cp4218dbg.ko $TARGET$SOURCE_MODULE
fi

#scripts
cp -p $SOURCE_BIN/3cstart.sh $TARGET$SOURCE_BIN
cp -p $SOURCE_BIN/3cstop.sh $TARGET$SOURCE_BIN
cp -p $SOURCE_BIN/3cload.sh $TARGET$SOURCE_BIN
cp -p $SOURCE_BIN/3cunload.sh $TARGET$SOURCE_BIN
cp -p $SOURCE_BIN/3cnetup.sh $TARGET$SOURCE_BIN
cp -p $SOURCE_BIN/3cnet2up.sh $TARGET$SOURCE_BIN
cp -p $SOURCE_BIN/3cnet3up.sh $TARGET$SOURCE_BIN
cp -p $SOURCE_BIN/3cnet4up.sh $TARGET$SOURCE_BIN
cp -p $SOURCE_BIN/3cnetdown.sh $TARGET$SOURCE_BIN
cp -p $SOURCE_BIN/3cnet2down.sh $TARGET$SOURCE_BIN
cp -p $SOURCE_BIN/3cnet3down.sh $TARGET$SOURCE_BIN
cp -p $SOURCE_BIN/3cnet4down.sh $TARGET$SOURCE_BIN

#config
cp -p /etc/3cp4218 $TARGET/etc

#service
cp -p /etc/cp4218.service $TARGET/etc

#bridged
cp -p $SOURCE_BIN/br2684ctl $TARGET$SOURCE_BIN

#panel
cp -p $SOURCE_BIN/3cpanel $TARGET$SOURCE_BIN
cp -p $SOURCE_BIN/3cpanel.glade $TARGET$SOURCE_BIN
cp -p $SOURCE_BIN/3cp4218-tux-small-left-35.xpm $TARGET$SOURCE_BIN
cp -p $SOURCE_LC_ES/3cpanel.glade.mo $TARGET$SOURCE_LC_ES
cp -p $SOURCE_LC_ES/3cpanel.mo $TARGET$SOURCE_LC_ES

#config
cp -p $SOURCE_BIN/3cconfig $TARGET$SOURCE_BIN
cp -p $SOURCE_BIN/3cconfig.glade $TARGET$SOURCE_BIN
cp -p $SOURCE_LC_ES/3cconfig.glade.mo $TARGET$SOURCE_LC_ES
cp -p $SOURCE_LC_ES/3cconfig.mo $TARGET$SOURCE_LC_ES


#
#build deb package
#

dpkg -b $TARGET $PACKAGE_NAME 
rm -rf $TARGET

